==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/SimpleShapeAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;A common base type for simple shape (currently circle and square) annotations.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SimpleShapeAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SimpleShapeAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseAnnotationType">
 *       <all>
 *         <element name="position" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <choice minOccurs="0">
 *                   <element name="rectangle" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/>
 *                 </choice>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="border" type="{http://schema.webpdf.de/1.0/operation}BorderType" minOccurs="0"/>
 *       </all>
 *       <attribute name="interiorColor" type="{http://schema.webpdf.de/1.0/operation}RgbColorType" default="#000000" />
 *       <attribute name="drawMode" type="{http://schema.webpdf.de/1.0/operation}DrawModeType" default="fillAndStroke" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SimpleShapeAnnotationType", propOrder = {
    "position",
    "border"
})
@XmlSeeAlso({
    CircleAnnotationType.class,
    SquareAnnotationType.class
})
public class SimpleShapeAnnotationType
    extends BaseAnnotationType
{

    protected SimpleShapeAnnotationType.Position position;
    protected BorderType border;
    @XmlAttribute(name = "interiorColor")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String interiorColor;
    @XmlAttribute(name = "drawMode")
    protected DrawModeType drawMode;

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleShapeAnnotationType.Position }
     *     
     */
    public SimpleShapeAnnotationType.Position getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleShapeAnnotationType.Position }
     *     
     */
    public void setPosition(SimpleShapeAnnotationType.Position value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the border property.
     * 
     * @return
     *     possible object is
     *     {@link BorderType }
     *     
     */
    public BorderType getBorder() {
        return border;
    }

    /**
     * Sets the value of the border property.
     * 
     * @param value
     *     allowed object is
     *     {@link BorderType }
     *     
     */
    public void setBorder(BorderType value) {
        this.border = value;
    }

    public boolean isSetBorder() {
        return (this.border!= null);
    }

    /**
     * Gets the value of the interiorColor property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInteriorColor() {
        if (interiorColor == null) {
            return "#000000";
        } else {
            return interiorColor;
        }
    }

    /**
     * Sets the value of the interiorColor property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInteriorColor(String value) {
        this.interiorColor = value;
    }

    public boolean isSetInteriorColor() {
        return (this.interiorColor!= null);
    }

    /**
     * Gets the value of the drawMode property.
     * 
     * @return
     *     possible object is
     *     {@link DrawModeType }
     *     
     */
    public DrawModeType getDrawMode() {
        if (drawMode == null) {
            return DrawModeType.FILL_AND_STROKE;
        } else {
            return drawMode;
        }
    }

    /**
     * Sets the value of the drawMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link DrawModeType }
     *     
     */
    public void setDrawMode(DrawModeType value) {
        this.drawMode = value;
    }

    public boolean isSetDrawMode() {
        return (this.drawMode!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <choice minOccurs="0">
     *         <element name="rectangle" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/>
     *       </choice>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "rectangle"
    })
    public static class Position {

        protected RectangleType rectangle;

        /**
         * Gets the value of the rectangle property.
         * 
         * @return
         *     possible object is
         *     {@link RectangleType }
         *     
         */
        public RectangleType getRectangle() {
            return rectangle;
        }

        /**
         * Sets the value of the rectangle property.
         * 
         * @param value
         *     allowed object is
         *     {@link RectangleType }
         *     
         */
        public void setRectangle(RectangleType value) {
            this.rectangle = value;
        }

        public boolean isSetRectangle() {
            return (this.rectangle!= null);
        }

    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SimpleShapeAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;A common base type for simple shape (currently circle and square) annotations.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SimpleShapeAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SimpleShapeAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseAnnotationType">
 *       <all>
 *         <element name="position" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <choice minOccurs="0">
 *                   <element name="rectangle" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/>
 *                 </choice>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="border" type="{http://schema.webpdf.de/1.0/operation}BorderType" minOccurs="0"/>
 *       </all>
 *       <attribute name="interiorColor" type="{http://schema.webpdf.de/1.0/operation}RgbColorType" default="#000000" />
 *       <attribute name="drawMode" type="{http://schema.webpdf.de/1.0/operation}DrawModeType" default="fillAndStroke" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SimpleShapeAnnotationType", propOrder = {
    "position",
    "border"
})
@XmlSeeAlso({
    CircleAnnotationType.class,
    SquareAnnotationType.class
})
public class SimpleShapeAnnotationType
    extends BaseAnnotationType
{

    protected SimpleShapeAnnotationType.Position position;
    protected BorderType border;
    @XmlAttribute(name = "interiorColor")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String interiorColor;
    @XmlAttribute(name = "drawMode")
    protected DrawModeType drawMode;

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleShapeAnnotationType.Position }
     *     
     */
    public SimpleShapeAnnotationType.Position getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleShapeAnnotationType.Position }
     *     
     */
    public void setPosition(SimpleShapeAnnotationType.Position value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the border property.
     * 
     * @return
     *     possible object is
     *     {@link BorderType }
     *     
     */
    public BorderType getBorder() {
        return border;
    }

    /**
     * Sets the value of the border property.
     * 
     * @param value
     *     allowed object is
     *     {@link BorderType }
     *     
     */
    public void setBorder(BorderType value) {
        this.border = value;
    }

    public boolean isSetBorder() {
        return (this.border!= null);
    }

    /**
     * Gets the value of the interiorColor property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInteriorColor() {
        if (interiorColor == null) {
            return "#000000";
        } else {
            return interiorColor;
        }
    }

    /**
     * Sets the value of the interiorColor property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInteriorColor(String value) {
        this.interiorColor = value;
    }

    public boolean isSetInteriorColor() {
        return (this.interiorColor!= null);
    }

    /**
     * Gets the value of the drawMode property.
     * 
     * @return
     *     possible object is
     *     {@link DrawModeType }
     *     
     */
    public DrawModeType getDrawMode() {
        if (drawMode == null) {
            return DrawModeType.FILL_AND_STROKE;
        } else {
            return drawMode;
        }
    }

    /**
     * Sets the value of the drawMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link DrawModeType }
     *     
     */
    public void setDrawMode(DrawModeType value) {
        this.drawMode = value;
    }

    public boolean isSetDrawMode() {
        return (this.drawMode!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <choice minOccurs="0">
     *         <element name="rectangle" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/>
     *       </choice>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "rectangle"
    })
    public static class Position {

        protected RectangleType rectangle;

        /**
         * Gets the value of the rectangle property.
         * 
         * @return
         *     possible object is
         *     {@link RectangleType }
         *     
         */
        public RectangleType getRectangle() {
            return rectangle;
        }

        /**
         * Sets the value of the rectangle property.
         * 
         * @param value
         *     allowed object is
         *     {@link RectangleType }
         *     
         */
        public void setRectangle(RectangleType value) {
            this.rectangle = value;
        }

        public boolean isSetRectangle() {
            return (this.rectangle!= null);
        }

    }

}
